__version__ = '0.0.0'

def getConfig(configList:list, section:str="DEFAULT", configFilePath:str='config.txt'):
    import configparser
    config = configparser.ConfigParser()

    def handleError(e:Exception):
        print('config.txt파일 오류')
        writeError(e)
        return False        

    for enc in ['utf-8','cp949']:
        try:
            config.read(configFilePath,encoding=enc)
            resList = [config[section][x] for x in configList]
            return resList
        except UnicodeDecodeError as e:
            decDrror = e
            continue
        except Exception as e: 
            return handleError(e)
    else:
        return handleError(decDrror)


def getNowStr(format:str = "%Y-%m-%d %H:%M:%S"):
    from datetime import datetime
    nowStr = datetime.now().strftime(format)

    return nowStr


def writeError(e:Exception, errorFilePath:str='error.txt', consoleLogging:bool=False):
    import traceback
    errLog = f"""{getNowStr()}
    [{type(e).__name__}] - {e.__doc__}
    function: {e.__traceback__.tb_frame.f_code.co_name}({e.args})
    traceback: {traceback.format_exc()}
    """
    fwrite(errLog, errorFilePath)
    if consoleLogging:
        print(errLog)


def fwrite(text, filePath:str="output.txt", encoding:str=None):
    def handleError(e:Exception):
        if e: writeError(e)
        return False

    text = str(text)
    textStr = text + '\n' if (not text) or (text[-1] != '\n') else text
    encList = [encoding] if encoding else ['utf-8','cp949']

    encError = None
    for enc in encList:
        try:
            with open(filePath, 'a', encoding=enc) as f:
                f.write(textStr)
            break
        except UnicodeEncodeError as e: 
            encError = e
            continue
        except Exception as e: 
            handleError(e)
            break
    else:
        handleError(encError)


if __name__ == "__main__":
    ...


__version__ = '0.0.5'

def getInsertQuery(tableName:str, dataDict:dict, duplicateUpdate:bool=False, updateItems:list=[])->str:
    '''
    dataDict    = {'col1':'data1','col2':'data2'}
    updateItems = ['col1','col2']
    '''
    query = ''
    itemStr = ','.join(['`'+str(x)+'`' for x in list(dataDict.keys())])
    valueStr= ','.join(['Null' if x is None else "'"+str(x)+"'" for x in list(dataDict.values())])
    updateStr = "ON DUPLICATE KEY UPDATE " + ','.join(["`"+str(x)+"`='"+str(dataDict[x])+"'" for x in updateItems]) if duplicateUpdate else ''
    
    query = rf"""INSERT INTO `{tableName}` ({itemStr}) VALUES ({valueStr}) {updateStr};"""

    return query


def getSelectQuery(tableName:str,  items:list=[], where:list=[], sort:dict={}, distinct:bool=False)->str:
    '''
    items = ['col1', 'col2']
    where = ["`col1` = 'apple'", "`col2` < 13"]
    sort  = {"col1":"ASC", "col1":"DESC"} # value - ASC/DESC
    '''
    query = ''
    itemStr = ','.join(['`'+str(x)+'`' for x in items]) if items != [] else '*'
    whereStr = ("WHERE " + 'AND'.join(['('+str(x)+')' for x in where])) if where != [] else ''
    sortStr = ("ORDER BY " + ','.join(["`"+str(x)+"` "+str(sort[x]).upper()+"" for x in sort.keys()])) if sort != {} else ''
    distinctStr = "DISTINCT" if distinct else ''

    query = rf"""SELECT {distinctStr} {itemStr} FROM `{tableName}` {whereStr} {sortStr};"""

    return query


def getTruncateQuery(tableName:str)->str:
    query = f"TRUNCATE TABLE {tableName};"
    return query


def getDeleteQuery(tableName:str, where:list=[])->str:
    '''
    where = ["`col1` = 'apple'", "`col2` < 13"]
    '''

    query = ''
    whereStr = ("WHERE " + 'AND'.join(['('+str(x)+')' for x in where])) if where != [] else ''

    query = rf"""DELETE FROM `{tableName}` {whereStr};"""

    return query

def getUpdateQuery(tableName:str, dataDict:dict, where:list=[])->str:
    '''
    where = ["`col1` = 'apple'", "`col2` < 13"]
    dataDict    = {'col1':'data1','col2':'data2'}
    '''
    query = ''
    whereStr = ("WHERE " + 'AND'.join(['('+str(x)+')' for x in where])) if where != [] else ''
    setStr = "SET" + ','.join([f"`{x}` = '{dataDict[x]}'" for x in dataDict])

    query = rf"""UPDATE `{tableName}` {setStr} {whereStr};"""

    return query

if __name__ == "__main__":
    print(getDeleteQuery('powder',where=["seq = 1", "name_ko = '코발트'"]))


from setuptools import setup, find_packages
from igzg import __version__ as igzgVersion

setup(
    name = 'igzg',
    version = igzgVersion,
    description = 'PYPI tutorial package creation written by suhyeojee',
    author = 'suhyeojee',
    author_email = 'suhyeojee@gmail.com',
    url = 'https://github.com/suhyeojee/igzg',
    packages = find_packages(exclude=[]),
    package_data = {},
    include_package_data = False,
    zip_safe = False,
    classifiers = [
        'Programming Language :: Python :: 3',
        "License :: OSI Approved :: MIT License",
        "Operating System :: Microsoft :: Windows",
    ],
    python_requires = '>=3.6',
    install_requires = [],
)

